import { AncestorEntry, Descendant, Editor, Element, ElementEntry, Location, Mark, MarkEntry, NodeEntry, NodeMatch, Path, Point, Range, Span, Text, TextEntry } from '../../..';
export declare const LocationQueries: {
    /**
     * Get the marks that are "active" at a location. These are the
     * marks that will be added to any text that is inserted.
     *
     * The `union: true` option can be passed to create a union of marks across
     * the text nodes in the selection, instead of creating an intersection, which
     * is the default.
     *
     * Note: to obey common rich text behavior, if the selection is collapsed at
     * the start of a text node and there are previous text nodes in the same
     * block, it will carry those marks forward from the previous text node. This
     * allows for continuation of marks from previous words.
     */
    activeMarks(editor: Editor, options?: {
        at?: Path | Point | Range | undefined;
        union?: boolean | undefined;
        hanging?: boolean | undefined;
    }): Mark[];
    /**
     * Get the point after a location.
     */
    after(editor: Editor, at: Location, options?: {
        distance?: number | undefined;
        unit?: "offset" | "character" | "word" | "line" | "block" | undefined;
    }): Point | undefined;
    /**
     * Get the common ancestor node of a location.
     */
    ancestor(editor: Editor, at: Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): AncestorEntry;
    /**
     * Get the point before a location.
     */
    before(editor: Editor, at: Location, options?: {
        distance?: number | undefined;
        unit?: "offset" | "character" | "word" | "line" | "block" | undefined;
    }): Point | undefined;
    /**
     * Get the start and end points of a location.
     */
    edges(editor: Editor, at: Location): [Point, Point];
    /**
     * Iterate through all of the elements in the Editor.
     */
    elements(editor: Editor, options?: {
        at?: Path | Point | Range | Span | undefined;
        reverse?: boolean | undefined;
    }): Iterable<ElementEntry>;
    /**
     * Get the end point of a location.
     */
    end(editor: Editor, at: Location): Point;
    /**
     * Get the first node at a location.
     */
    first(editor: Editor, at: Location): NodeEntry;
    /**
     * Get the fragment at a location.
     */
    fragment(editor: Editor, at: Location): Descendant[];
    /**
     * Check if a point the start point of a location.
     */
    isStart(editor: Editor, point: Point, at: Location): boolean;
    /**
     * Check if a point is the end point of a location.
     */
    isEnd(editor: Editor, point: Point, at: Location): boolean;
    /**
     * Check if a point is an edge of a location.
     */
    isEdge(editor: Editor, point: Point, at: Location): boolean;
    /**
     * Get the last node at a location.
     */
    last(editor: Editor, at: Location): NodeEntry;
    /**
     * Get the leaf text node at a location.
     */
    leaf(editor: Editor, at: Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): TextEntry;
    /**
     * Iterate through all of the levels at a location.
     */
    levels(editor: Editor, options?: {
        at?: Path | Point | Range | undefined;
        reverse?: boolean | undefined;
    }): Iterable<NodeEntry>;
    /**
     * Iterate through all of the text nodes in the Editor.
     */
    marks(editor: Editor, options?: {
        at?: Path | Point | Range | Span | undefined;
        match?: Partial<Mark> | ((entry: MarkEntry) => boolean) | undefined;
        mode?: "all" | "first" | "distinct" | "universal" | undefined;
        reverse?: boolean | undefined;
        continuing?: boolean | undefined;
    }): Iterable<MarkEntry>;
    /**
     * Get the first matching node in a single branch of the document.
     */
    match(editor: Editor, at: Location, match: NodeMatch): NodeEntry | undefined;
    /**
     * Iterate through all of the nodes that match.
     */
    matches(editor: Editor, options: {
        at?: Path | Point | Range | Span | undefined;
        match?: "block" | "element" | "inline" | "inline-element" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<Text> | ((entry: NodeEntry) => boolean) | undefined;
        reverse?: boolean | undefined;
    }): Iterable<NodeEntry>;
    /**
     * Get the matching node in the branch of the document after a location.
     */
    next(editor: Editor, at: Location, match: NodeMatch): NodeEntry | undefined;
    /**
     * Get the node at a location.
     */
    node(editor: Editor, at: Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): NodeEntry;
    /**
     * Iterate through all of the nodes in the Editor.
     */
    nodes(editor: Editor, options?: {
        at?: Path | Point | Range | Span | undefined;
        match?: "block" | "element" | "inline" | "inline-element" | "text" | "editor" | "void" | Partial<Editor> | Partial<Element> | Partial<Text> | ((entry: NodeEntry) => boolean) | undefined;
        mode?: "all" | "highest" | undefined;
        reverse?: boolean | undefined;
    }): Iterable<NodeEntry>;
    /**
     * Get the parent node of a location.
     */
    parent(editor: Editor, at: Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): AncestorEntry;
    /**
     * Get the path of a location.
     */
    path(editor: Editor, at: Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): Path;
    /**
     * Get the start or end point of a location.
     */
    point(editor: Editor, at: Location, options?: {
        edge?: "start" | "end" | undefined;
    }): Point;
    /**
     * Iterate through all of the positions in the document where a `Point` can be
     * placed.
     *
     * By default it will move forward by individual offsets at a time,  but you
     * can pass the `unit: 'character'` option to moved forward one character, word,
     * or line at at time.
     *
     * Note: void nodes are treated as a single point, and iteration will not
     * happen inside their content.
     */
    positions(editor: Editor, options?: {
        at?: Path | Point | Range | undefined;
        unit?: "offset" | "character" | "word" | "line" | "block" | undefined;
        reverse?: boolean | undefined;
    }): Iterable<Point>;
    /**
     * Get the matching node in the branch of the document before a location.
     */
    previous(editor: Editor, at: Location, match: NodeMatch): NodeEntry | undefined;
    /**
     * Get a range of a location.
     */
    range(editor: Editor, at: Location, to?: Path | Point | Range | undefined): Range;
    /**
     * Get the start point of a location.
     */
    start(editor: Editor, at: Location): Point;
    /**
     * Get the text content of a location.
     *
     * Note: the text of void nodes is presumed to be an empty string, regardless
     * of what their actual content is.
     */
    text(editor: Editor, at: Location): string;
    /**
     * Iterate through all of the text nodes in the Editor.
     */
    texts(editor: Editor, options?: {
        at?: Path | Point | Range | Span | undefined;
        reverse?: boolean | undefined;
    }): Iterable<TextEntry>;
};
//# sourceMappingURL=location.d.ts.map